@@ -16,9 +16,13 @@ pub(crate) trait HasSpecs {
             .map(|package| {
                 let spec =
                     MatchSpec::from_str(package, ParseStrictness::Lenient).into_diagnostic()?;
-                let name = spec.name.clone().ok_or_else(|| {
+                let name_matcher = spec.name.clone().ok_or_else(|| {
                     miette::miette!("could not find package name in MatchSpec {}", spec)
                 })?;
+                let name = name_matcher
+                    .as_exact()
+                    .cloned()
+                    .ok_or_else(|| miette::miette!("wildcard package names are not supported"))?;
                 Ok((name, spec))
             })
             .collect()
