@@ -144,11 +144,11 @@ impl EnvironmentHash {
 
         // Hash the packages
         let mut urls = Vec::new();
-        if let Some(env) = lock_file.environment(run_environment.name().as_str()) {
-            if let Some(packages) = env.packages(run_environment.best_platform()) {
-                for package in packages {
-                    urls.push(package.location().to_string())
-                }
+        if let Some(env) = lock_file.environment(run_environment.name().as_str())
+            && let Some(packages) = env.packages(run_environment.best_platform())
+        {
+            for package in packages {
+                urls.push(package.location().to_string())
             }
         }
         urls.sort();
@@ -526,7 +526,7 @@ pub async fn get_update_lock_file_and_prefix<'env>(
     filter: &InstallFilter,
 ) -> miette::Result<(LockFileDerivedData<'env>, Prefix)> {
     let (lock_file, prefixes) = get_update_lock_file_and_prefixes(
-        &[environment.clone()],
+        std::slice::from_ref(environment),
         update_mode,
         update_lock_file_options,
         reinstall_packages,
