@@ -260,34 +260,34 @@ pub(crate) fn validate_system_meets_environment_requirements(
     }
 
     // Check if the wheel tags match the system virtual packages if there are any
-    if environment.has_pypi_packages(platform) {
-        if let Some(pypi_packages) = environment.pypi_packages(platform) {
-            // Get python record from conda packages
-            let python_record = conda_records
-                .iter()
-                .find(|record| is_python_record(record))
-                .ok_or(MachineValidationError::NoPythonRecordFound(platform))?;
+    if environment.has_pypi_packages(platform)
+        && let Some(pypi_packages) = environment.pypi_packages(platform)
+    {
+        // Get python record from conda packages
+        let python_record = conda_records
+            .iter()
+            .find(|record| is_python_record(record))
+            .ok_or(MachineValidationError::NoPythonRecordFound(platform))?;
 
-            // Check if all the wheel tags match the system virtual packages
-            let pypi_packages = pypi_packages
-                .map(|(pkg_data, _)| pkg_data.clone())
-                .collect_vec();
+        // Check if all the wheel tags match the system virtual packages
+        let pypi_packages = pypi_packages
+            .map(|(pkg_data, _)| pkg_data.clone())
+            .collect_vec();
 
-            let wheels = get_wheels_from_pypi_package_data(pypi_packages);
+        let wheels = get_wheels_from_pypi_package_data(pypi_packages);
 
-            let uv_system_tags =
-                get_tags_from_machine(&system_virtual_packages, platform, python_record)?;
+        let uv_system_tags =
+            get_tags_from_machine(&system_virtual_packages, platform, python_record)?;
 
-            // Check if all the wheel tags match the system virtual packages
-            for wheel in wheels {
-                if !wheel.is_compatible(&uv_system_tags) {
-                    return Err(MachineValidationError::WheelTagsMismatch(
-                        wheel.to_string(),
-                        uv_system_tags.to_string(),
-                    ));
-                }
-                tracing::debug!("Wheel: {} matches the system", wheel);
+        // Check if all the wheel tags match the system virtual packages
+        for wheel in wheels {
+            if !wheel.is_compatible(&uv_system_tags) {
+                return Err(MachineValidationError::WheelTagsMismatch(
+                    wheel.to_string(),
+                    uv_system_tags.to_string(),
+                ));
             }
+            tracing::debug!("Wheel: {} matches the system", wheel);
         }
     }
     Ok(true)
