@@ -46,6 +46,9 @@ pub struct TomlManifest {
     pub host_dependencies: Option<PixiSpanned<UniquePackageMap>>,
     pub build_dependencies: Option<PixiSpanned<UniquePackageMap>>,
     pub pypi_dependencies: Option<PixiSpanned<IndexMap<PypiPackageName, PixiPypiSpec>>>,
+    pub dev_dependencies: Option<
+        PixiSpanned<IndexMap<rattler_conda_types::PackageName, pixi_spec::TomlLocationSpec>>,
+    >,
 
     /// Additional information to activate an environment.
     pub activation: Option<PixiSpanned<Activation>>,
@@ -155,6 +158,7 @@ impl TomlManifest {
             host_dependencies: self.host_dependencies,
             build_dependencies: self.build_dependencies,
             pypi_dependencies: self.pypi_dependencies.map(PixiSpanned::into_inner),
+            dev_dependencies: self.dev_dependencies.map(PixiSpanned::into_inner),
             activation: self.activation.map(PixiSpanned::into_inner),
             tasks: self.tasks.map(PixiSpanned::into_inner).unwrap_or_default(),
             warnings: self.warnings,
@@ -517,6 +521,9 @@ impl<'de> toml_span::Deserialize<'de> for TomlManifest {
         let pypi_dependencies = th
             .optional::<TomlWith<_, PixiSpanned<TomlIndexMap<_, Same>>>>("pypi-dependencies")
             .map(TomlWith::into_inner);
+        let dev = th
+            .optional::<TomlWith<_, PixiSpanned<TomlIndexMap<_, Same>>>>("dev")
+            .map(TomlWith::into_inner);
         let activation = th.optional("activation");
         let tasks = th
             .optional::<TomlWith<_, PixiSpanned<TomlHashMap<_, Same>>>>("tasks")
@@ -578,6 +585,7 @@ impl<'de> toml_span::Deserialize<'de> for TomlManifest {
             host_dependencies,
             build_dependencies,
             pypi_dependencies,
+            dev_dependencies: dev,
             activation,
             tasks,
             feature,
@@ -988,6 +996,181 @@ mod test {
         ));
     }
 
+    #[test]
+    fn test_parse_dev_path() {
+        let manifest = WorkspaceManifest::from_toml_str(
+            r#"
+        [workspace]
+        name = "test"
+        channels = []
+        platforms = ["linux-64"]
+
+        [dev]
+        test-package = { path = "../test-package" }
+        "#,
+        )
+        .unwrap();
+
+        let dev_deps = manifest
+            .default_feature()
+            .dev_dependencies(None)
+            .expect("should have dev dependencies");
+
+        assert_eq!(dev_deps.iter().count(), 1);
+        assert!(dev_deps.contains_key("test-package"));
+    }
+
+    #[test]
+    fn test_parse_dev_git() {
+        let manifest = WorkspaceManifest::from_toml_str(
+            r#"
+        [workspace]
+        name = "test"
+        channels = []
+        platforms = ["linux-64"]
+
+        [dev]
+        my-lib = { git = "https://github.com/example/my-lib.git", branch = "main" }
+        "#,
+        )
+        .unwrap();
+
+        let dev_deps = manifest
+            .default_feature()
+            .dev_dependencies(None)
+            .expect("should have dev dependencies");
+
+        assert_eq!(dev_deps.iter().count(), 1);
+        assert!(dev_deps.contains_key("my-lib"));
+    }
+
+    #[test]
+    fn test_parse_dev_multiple() {
+        let manifest = WorkspaceManifest::from_toml_str(
+            r#"
+        [workspace]
+        name = "test"
+        channels = []
+        platforms = ["linux-64"]
+
+        [dev]
+        pkg-a = { path = "../pkg-a" }
+        pkg-b = { git = "https://github.com/example/pkg-b.git" }
+        pkg-c = { url = "https://example.com/pkg-c.tar.gz" }
+        "#,
+        )
+        .unwrap();
+
+        let dev_deps = manifest
+            .default_feature()
+            .dev_dependencies(None)
+            .expect("should have develop dependencies");
+
+        assert_eq!(dev_deps.iter().count(), 3);
+        assert!(dev_deps.contains_key("pkg-a"));
+        assert!(dev_deps.contains_key("pkg-b"));
+        assert!(dev_deps.contains_key("pkg-c"));
+    }
+
+    #[test]
+    fn test_parse_feature_dev() {
+        let manifest = WorkspaceManifest::from_toml_str(
+            r#"
+        [workspace]
+        name = "test"
+        channels = []
+        platforms = ["linux-64"]
+
+        [feature.extra.dev]
+        feature-pkg = { path = "../feature-pkg" }
+
+        [environments]
+        default = []
+        extra = ["extra"]
+        "#,
+        )
+        .unwrap();
+
+        // Default feature should not have develop dependencies
+        assert!(manifest.default_feature().dev_dependencies(None).is_none());
+
+        // Extra feature should have develop dependencies
+        let extra_feature = manifest
+            .feature("extra")
+            .expect("extra feature should exist");
+        let dev_deps = extra_feature
+            .dev_dependencies(None)
+            .expect("should have develop dependencies");
+
+        assert_eq!(dev_deps.iter().count(), 1);
+        assert!(dev_deps.contains_key("feature-pkg"));
+    }
+
+    #[test]
+    fn test_parse_target_dev() {
+        let manifest = WorkspaceManifest::from_toml_str(
+            r#"
+        [workspace]
+        name = "test"
+        channels = []
+        platforms = ["linux-64", "win-64"]
+
+        [target.linux-64.dev]
+        linux-pkg = { path = "../linux-pkg" }
+
+        [target.win-64.dev]
+        windows-pkg = { path = "../windows-pkg" }
+        "#,
+        )
+        .unwrap();
+
+        let linux_deps = manifest
+            .default_feature()
+            .dev_dependencies(Some(Platform::Linux64))
+            .expect("should have linux dev dependencies");
+
+        assert_eq!(linux_deps.iter().count(), 1);
+        assert!(linux_deps.contains_key("linux-pkg"));
+
+        let windows_deps = manifest
+            .default_feature()
+            .dev_dependencies(Some(Platform::Win64))
+            .expect("should have windows dev dependencies");
+
+        assert_eq!(windows_deps.iter().count(), 1);
+        assert!(windows_deps.contains_key("windows-pkg"));
+    }
+
+    #[test]
+    fn test_parse_dev_invalid_no_source_type() {
+        assert_snapshot!(expect_parse_failure(
+            r#"
+        [workspace]
+        name = "test"
+        channels = []
+        platforms = ["linux-64"]
+
+        [dev]
+        bad-pkg = { subdirectory = "subdir" }
+        "#,
+        ));
+    }
+
+    #[test]
+    fn test_parse_dev_invalid_multiple_sources() {
+        assert_snapshot!(expect_parse_failure(
+            r#"
+        [workspace]
+        name = "test"
+        channels = []
+        platforms = ["linux-64"]
+
+        [dev]
+        bad-pkg = { path = "../path", git = "https://github.com/example/repo.git" }
+        "#,
+        ));
+    }
+
     #[test]
     fn test_project_deprecation_warning() {
         assert_snapshot!(
