@@ -2,7 +2,7 @@ use fs_err::create_dir_all;
 use miette::{Context, IntoDiagnostic};
 use pixi_config::{self, Config, get_cache_dir};
 use pixi_consts::consts;
-use pixi_utils::reqwest::uv_middlewares;
+use pixi_utils::reqwest::{should_use_native_tls_for_uv, uv_middlewares};
 use pixi_uv_conversions::{ConversionError, to_uv_trusted_host};
 use tracing::debug;
 use uv_cache::Cache;
@@ -31,6 +31,9 @@ pub struct UvResolutionContext {
     pub extra_middleware: ExtraMiddleware,
     pub proxies: Vec<reqwest::Proxy>,
     pub tls_no_verify: bool,
+    /// Whether UV should use native TLS (system certificates).
+    /// This is computed based on the `tls-root-certs` config and the TLS feature used.
+    pub use_native_tls: bool,
     pub package_config_settings: PackageConfigSettings,
     pub extra_build_requires: ExtraBuildRequires,
     pub extra_build_variables: ExtraBuildVariables,
@@ -87,6 +90,7 @@ impl UvResolutionContext {
             extra_middleware: ExtraMiddleware(uv_middlewares(config)),
             proxies: config.get_proxies().into_diagnostic()?,
             tls_no_verify: config.tls_no_verify(),
+            use_native_tls: should_use_native_tls_for_uv(config),
             package_config_settings: PackageConfigSettings::default(),
             extra_build_requires: ExtraBuildRequires::default(),
             extra_build_variables: ExtraBuildVariables::default(),
