@@ -1,7 +1,9 @@
 mod conversions;
+mod git_url;
 mod requirements;
 mod types;
 
 pub use conversions::*;
+pub use git_url::*;
 pub use requirements::*;
 pub use types::*;
