@@ -178,7 +178,12 @@ pub fn as_uv_req(
             if canonicalized.is_dir() {
                 RequirementSource::Directory {
                     install_path: canonicalized.into_boxed_path(),
-                    editable: Some(editable.unwrap_or_default()),
+                    // Always set editable to false during resolution.
+                    // Editability doesn't affect resolution and is looked up from the
+                    // manifest at install time. This allows different environments in a
+                    // solve-group to have different editability settings without causing
+                    // "conflicting URLs" errors from the uv resolver.
+                    editable: Some(false),
                     url: verbatim,
                     // TODO: we could see if we ever need this
                     // AFAICS it would be useful for constrainging dependencies
